@@ -115,6 +115,9 @@ try {
         $archive = end($archive_list);
     }
 
+    // search SPAM
+    $App->setSession('isSpam',$AppState->getValue('isSpam'));
+
     // Language
     if ($App->getParam('interfaceLanguage')) {
         $AppState->saveValue('userLanguage',$App->getParam('interfaceLanguage'));
