@@ -39,16 +39,16 @@ if (! $passwd) {
     auth_exit($message);
 }
 
-$User = new User($userid);
+$USER = new User($userid);
 try {
     if ($authscript && is_readable($authscript)) {
-        $User->loadExternal($authscript,$passwd);
+        $USER->loadExternal($authscript,$passwd);
     }
     else {
         $App->log("Cannot read \"$authscript\". Fallback authentication.");
-        $User->load();
+        $USER->load();
         // check authentication
-        if ($User->password != md5($passwd)) {
+        if ($USER->password != md5($passwd)) {
             throw new Exception('ERR_AUTH');
         }
     }
@@ -61,6 +61,6 @@ catch (Exception $e) {
 }
 
 // Authentication successful
-$App->setSession('USER',$User);
+$App->setSession('USER',$USER);
 
 ?>
